==> mbdyn-1.2.7.tar.gz: mbdyn-1.2.7/mbdyn/base/dofown.cc <==
/* 
 * MBDyn (C) is a multibody analysis code. 
 * http://www.mbdyn.org
 *
 * Copyright (C) 1996-2007
 *
 * Pierangelo Masarati	<masarati@aero.polimi.it>
 * Paolo Mantegazza	<mantegazza@aero.polimi.it>
 *
 * Dipartimento di Ingegneria Aerospaziale - Politecnico di Milano
 * via La Masa, 34 - 20156 Milano, Italy
 * http://www.aero.polimi.it
 *
 * Changing this copyright notice is forbidden.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation (version 2 of the License).
 * 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#include <mbconfig.h>           /* This goes first in every *.c,*.cc file */
#endif /* HAVE_CONFIG_H */

#include <dofown.h>
#include <solman.h>

doublereal
DofOwner::dGetScale(void) const
{
	return dScale;
}

void
DofOwner::SetScale(const doublereal& d)
{
	dScale = d;
}

DofOwnerOwner::DofOwnerOwner(const DofOwner* pDO) 
: pDofOwner(pDO)
{ 
	ASSERT(pDofOwner != NULL);
}
   
void 
DofOwnerOwner::SetInitialValue(VectorHandler& /* X */ ) const 
{ 
	NO_OP; 
}

==> mbdyn-1.3.9.tar.gz: mbdyn-1.3.9/mbdyn/base/dofown.cc <==
/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/dofown.cc,v 1.11 2009/01/04 18:05:03 masarati Exp $ */
/* 
 * MBDyn (C) is a multibody analysis code. 
 * http://www.mbdyn.org
 *
 * Copyright (C) 1996-2009
 *
 * Pierangelo Masarati	<masarati@aero.polimi.it>
 * Paolo Mantegazza	<mantegazza@aero.polimi.it>
 *
 * Dipartimento di Ingegneria Aerospaziale - Politecnico di Milano
 * via La Masa, 34 - 20156 Milano, Italy
 * http://www.aero.polimi.it
 *
 * Changing this copyright notice is forbidden.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation (version 2 of the License).
 * 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#include <mbconfig.h>           /* This goes first in every *.c,*.cc file */
#endif /* HAVE_CONFIG_H */

#include <dofown.h>
#include <solman.h>

doublereal
DofOwner::dGetScale(void) const
{
	return dScale;
}

void
DofOwner::SetScale(const doublereal& d)
{
	dScale = d;
}

DofOwnerOwner::DofOwnerOwner(const DofOwner* pDO) 
: pDofOwner(pDO)
{ 
	ASSERT(pDofOwner != NULL);
}
   
void 
DofOwnerOwner::SetInitialValue(VectorHandler& /* X */ )
{ 
	NO_OP; 
}
